"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const isRootSchema = (schema) => Boolean(schema.id || schema.$id);
const simplifySchema = (schema) => {
    const cleaned = Object.assign({}, schema);
    delete cleaned.$schema;
    delete cleaned.id;
    delete cleaned.$id;
    delete cleaned.definitions;
    return cleaned;
};
const isSchemaADupe = (target, subject) => {
    if (target === subject) {
        return false;
    }
    if (isRootSchema(target) || !isRootSchema(subject)) {
        return false;
    }
    const simpleSubject = simplifySchema(subject);
    const targetStr = JSON.stringify(target);
    const subjectStr = JSON.stringify(simpleSubject);
    const isEmpty = targetStr === '{}';
    return !isEmpty && targetStr === subjectStr;
};
const findDupeSchema = (target, schemas) => {
    for (const schema of schemas) {
        if (isSchemaADupe(target, schema)) {
            return schema;
        }
    }
};
function resolveDupes(schemas) {
    let rootSchemas = schemas.filter(isRootSchema);
    const recursivelyReplaceDupes = (obj) => {
        if (obj && obj instanceof Object) {
            const schemaRoot = findDupeSchema(obj, schemas);
            if (schemaRoot) {
                return { $ref: schemaRoot.$id || schemaRoot.id };
            }
            else {
                obj = obj instanceof Array ? [...obj] : Object.assign({}, obj);
                Object.keys(obj).forEach((key) => {
                    obj[key] = recursivelyReplaceDupes(obj[key]);
                });
            }
        }
        return obj;
    };
    rootSchemas = rootSchemas.map(recursivelyReplaceDupes);
    const newSchemas = schemas.map(recursivelyReplaceDupes);
    return newSchemas;
}
exports.resolveDupes = resolveDupes;
//# sourceMappingURL=resolveDupes.js.map